@@ -12,10 +12,10 @@ Example operations:
 """
 
 import os, sys, re
-from output import instant_warning, instant_assert, instant_debug
-from paths import get_default_cache_dir, validate_cache_dir
-from signatures import compute_checksum
-from locking import get_lock, release_lock
+from .output import instant_warning, instant_assert, instant_debug
+from .paths import get_default_cache_dir, validate_cache_dir
+from .signatures import compute_checksum
+from .locking import get_lock, release_lock
 
 # TODO: We could make this an argument, but it's used indirectly several places so take care.
 _modulename_prefix = "instant_module_"
@@ -35,7 +35,7 @@ def import_module_directly(path, modulename):
     e = None
     try:
         module = __import__(modulename)
-    except Exception, e:
+    except Exception as e:
         instant_warning("In instant.import_module_directly: Failed to import module '%s' from '%s';\n%s:%s;" % (modulename, path, type(e).__name__, e))
         module = None
     finally:
@@ -59,7 +59,7 @@ def place_module_in_memory_cache(moduleid, module):
 
 
 def is_valid_module_name(name):
-    NAMELENGTHLIMIT = 100
+    NAMELENGTHLIMIT = 200
     return len(name) < NAMELENGTHLIMIT and bool(re.search(r"^[a-zA-Z_][\w]*$", name))
 
 
@@ -104,7 +104,7 @@ def check_memory_cache(moduleid):
         if module: return module, moduleids
         moduleids.append(moduleid)
     
-    instant_debug("In instant.check_memory_cache: Failed to find module.")
+    instant_debug("In instant.check_memory_cache: Failed to find module: %s." % moduleid)
     return None, moduleids
 
 
@@ -126,7 +126,7 @@ def check_disk_cache(modulename, cache_dir, moduleids):
                 release_lock(lock)
                 return module
             else:
-                instant_debug("In instant.check_disk_cache: Failed to imported "\
+                instant_debug("In instant.check_disk_cache: Failed to import "\
                               "module '%s' from '%s'." % (modulename, path))
     
     # All attempts failed
