@@ -1,7 +1,7 @@
 """This module contains helper functions for working with checksums."""
 
 import hashlib
-from output import instant_assert, instant_debug, instant_error
+from .output import instant_assert, instant_debug, instant_error
 
 def compute_checksum(text="", filenames=[]):
     """
@@ -19,7 +19,7 @@ def compute_checksum(text="", filenames=[]):
         instant_debug("Adding file '%s' to checksum." % filename)
         try:
             fp = open(filename, 'rb')
-        except IOError, e:
+        except IOError as e:
             instant_error("Can't open file '%s': %s" % (filename, e))
         
         try:
@@ -28,7 +28,7 @@ def compute_checksum(text="", filenames=[]):
                 if not data:
                     break
                 m.update(data)
-        except IOError, e:
+        except IOError as e:
             instant_error("I/O error reading '%s': %s" % (filename, e))
         
         fp.close() 
@@ -39,13 +39,13 @@ def compute_checksum(text="", filenames=[]):
 def _test():
     signature = "(Test signature)"
     files = ["signatures.py", "__init__.py"]
-    print
-    print "Signature:", repr(signature)
-    print "Checksum:", compute_checksum(signature, [])
-    print
-    print "Files:", files
-    print "Checksum:", compute_checksum("", files)
-    print
+    print()
+    print("Signature:", repr(signature))
+    print("Checksum:", compute_checksum(signature, []))
+    print()
+    print("Files:", files)
+    print("Checksum:", compute_checksum("", files))
+    print()
 
 if __name__ == "__main__":
     _test()
