@@ -17,7 +17,7 @@ func = inline_vmtk(code, cache_dir="test_vmtk")
 
 v = vtkvmtk.vtkvmtkDoubleVector()
 v.Allocate(12,1)
-print "norm of v ", v.ComputeNorm()
+print("norm of v ", v.ComputeNorm())
 func(v)
-print "norm of v after test ", v.ComputeNorm()
+print("norm of v after test ", v.ComputeNorm())
 
