@@ -1,5 +1,10 @@
 
-from dolfin import *
+try:
+    from dolfin import *
+except:
+    print "dolfin not installed..."
+    exit()
+
 import instant
 
 cpp_code = """
@@ -21,15 +26,12 @@ d = 2.4
 
 include_dirs, flags, libs, libdirs = instant.header_and_libs_from_pkgconfig("dolfin")
 
-
-
 headers= ["dolfin.h"]
 
 func = instant.inline(cpp_code, system_headers=headers, include_dirs=include_dirs, libraries = libs, library_dirs = libdirs)  
 
-
 func(a, b, c, d)
 
-print b.array()
+print(b.array())
 
 
