@@ -22,15 +22,15 @@ a = numpy.arange(10000000); a = numpy.sin(a)
 t1 = time.time()
 sum1 = sum_func(a)
 t2 = time.time()
-print 'With instant:',t2-t1,'seconds'
+print('With instant:',t2-t1,'seconds')
 
 t1 = time.time() 
 sum2 =  numpy.sum(a)
 t2 = time.time()
-print 'With numpy:   ',t2-t1,'seconds'
+print('With numpy:   ',t2-t1,'seconds')
 
 difference = abs(sum1 - sum2) 
-print "The difference between the sums computed by numpy and instant is " + str(difference) 
+print("The difference between the sums computed by numpy and instant is " + str(difference)) 
 
 
 
