@@ -12,19 +12,19 @@ def compile_stuff(i):
     func = inline(c_code, cache_dir="test_locking_cache")
     s = func(i, 3)
     assert s == (i+3)
-    print "In run %d, result is %d as expected." % (i, s)
+    print("In run %d, result is %d as expected." % (i, s))
 
 if __name__ == "__main__":
     cmd = sys.argv[0]
     args = sys.argv[1:]
 
     if args:
-        print "Compiling with args =", args
+        print("Compiling with args =", args)
         i, = args
         compile_stuff(int(i))
 
     else:
-        print "Starting new processes to compile."
+        print("Starting new processes to compile.")
         def run(i):
             os.system("python %s %d" % (cmd, i))
         threads = []
